from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, String, Boolean, Int

Utgcns_V0_1_0 = CommandToolBuilder(tool="utgcns", base_command=["utgcns"], inputs=[ToolInput(tag="in_load_reads_partition", input_type=File(optional=True), prefix="-R", doc=InputDocumentation(doc="Load reads from partition file 'f'")), ToolInput(tag="in_load_tig_tgstore", input_type=String(optional=True), prefix="-T", doc=InputDocumentation(doc="v          Load tig from tgStore 't'.")), ToolInput(tag="in_test_computation_tig", input_type=File(optional=True), prefix="-t", doc=InputDocumentation(doc="Test the computation of the tig layout in 'file'\n'file' can be from:\n'tgStoreDump -d layout' (human readable layout format)\n'utgcns -L'             (human readable layout format)\n'utgcns -O'             (binary multialignment format)")), ToolInput(tag="in_import", input_type=File(optional=True), prefix="-import", doc=InputDocumentation(doc="Load tig and reads from file 'name' created with -export.  This\nis usually used by developers.")), ToolInput(tag="in_pbd_agc_on", input_type=Boolean(optional=True), prefix="-pbdagcon", doc=InputDocumentation(doc="Use pbdagcon (https://github.com/PacificBiosciences/pbdagcon).\nThis is fast and robust.  It is the default algorithm.  It does not\ngenerate a final multialignment output (the -v option will not show\nanything useful).")), ToolInput(tag="in_no_realign", input_type=Boolean(optional=True), prefix="-norealign", doc=InputDocumentation(doc="Disable alignment of reads back to the final consensus sequence.")), ToolInput(tag="in_write_computed_tigs_layout", input_type=File(optional=True), prefix="-L", doc=InputDocumentation(doc="Write computed tigs to layout output file 'layouts'")), ToolInput(tag="in_write_computed_tigs_fasta", input_type=File(optional=True), prefix="-A", doc=InputDocumentation(doc="Write computed tigs to fasta  output file 'fasta'")), ToolInput(tag="in_write_computed_tigs_fastq", input_type=File(optional=True), prefix="-Q", doc=InputDocumentation(doc="Write computed tigs to fastq  output file 'fastq'")), ToolInput(tag="in_export", input_type=File(optional=True), prefix="-export", doc=InputDocumentation(doc="Create a copy of the inputs needed to compute the tigs.  This\nfile can then be sent to the developers for debugging.  The tig(s)\nare not processed and no other outputs are created.  Ideally,\nonly one tig is selected (-u, below).")), ToolInput(tag="in_alias_for_tig", input_type=Boolean(optional=True), prefix="-u", doc=InputDocumentation(doc="Alias for -tig")), ToolInput(tag="in_minlength", input_type=String(optional=True), prefix="-minlength", doc=InputDocumentation(doc="Do not compute consensus for tigs shorter than l bases.")), ToolInput(tag="in_maxlength", input_type=String(optional=True), prefix="-maxlength", doc=InputDocumentation(doc="Do not compute consensus for tigs longer than l bases.")), ToolInput(tag="in_only_un_assem", input_type=Boolean(optional=True), prefix="-onlyunassem", doc=InputDocumentation(doc="Only compute consensus for unassembled tigs.")), ToolInput(tag="in_only_contig", input_type=Boolean(optional=True), prefix="-onlycontig", doc=InputDocumentation(doc="Only compute consensus for real unitigs/contigs.")), ToolInput(tag="in_no_repeat", input_type=Boolean(optional=True), prefix="-norepeat", doc=InputDocumentation(doc="Do not compute consensus for repeat tigs.")), ToolInput(tag="in_no_bubble", input_type=Boolean(optional=True), prefix="-nobubble", doc=InputDocumentation(doc="Do not compute consensus for bubble tigs.")), ToolInput(tag="in_no_singleton", input_type=Boolean(optional=True), prefix="-nosingleton", doc=InputDocumentation(doc="Do not compute consensus for singleton (single-read) tigs.")), ToolInput(tag="in_em", input_type=String(optional=True), prefix="-em", doc=InputDocumentation(doc="Don't ever allow alignments more than fraction m error")), ToolInput(tag="in_expect_alignments_at", input_type=String(optional=True), prefix="-l", doc=InputDocumentation(doc="Expect alignments of at least l bases")), ToolInput(tag="in_max_coverage", input_type=Int(optional=True), prefix="-maxcoverage", doc=InputDocumentation(doc="Use non-contained reads and the longest contained reads, up to\nC coverage, for consensus generation.  The default is 0, and will\nuse all reads.")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="-threads", doc=InputDocumentation(doc="Use 't' compute threads; default 1.")), ToolInput(tag="in_enable_debugging_option", input_type=Boolean(optional=True), prefix="-V", doc=InputDocumentation(doc="Enable debugging option 'verbosemultialign'.")), ToolInput(tag="in_input", input_type=String(), position=0, doc=InputDocumentation(doc="-S g            Load reads from sqStore 'g'")), ToolInput(tag="in_algorithm", input_type=String(), position=1, doc=InputDocumentation(doc="-quick          Stitch reads together to cover the contig.  The bases in the contig\nis formed from exactly one read; no consensus sequence is computed.\nThis is useful for checking intermediate assembly structure by mapping\nto reference, or as input to a polishing step.  Read positions will be\nincorrect, and no BAM output is possible.")), ToolInput(tag="in_aligner", input_type=String(), position=2, doc=InputDocumentation(doc="-edlib          Myers' O(ND) algorithm from Edlib (https://github.com/Martinsos/edlib).\nThis is the default (and, yes, there is no non-default aligner).")), ToolInput(tag="in_output", input_type=String(), position=3, doc=InputDocumentation(doc="-O results      Write computed tigs to binary output file 'results'")), ToolInput(tag="in_parameters", input_type=String(), position=0, doc=InputDocumentation(doc="-e e            Expect alignments at up to fraction e error")), ToolInput(tag="in_logging", input_type=String(), position=1, doc=InputDocumentation(doc="-v              Show multialigns."))], outputs=[ToolOutput(tag="out_write_computed_tigs_layout", output_type=File(optional=True), selector=InputSelector(input_to_select="in_write_computed_tigs_layout", type_hint=File()), doc=OutputDocumentation(doc="Write computed tigs to layout output file 'layouts'")), ToolOutput(tag="out_write_computed_tigs_fasta", output_type=File(optional=True), selector=InputSelector(input_to_select="in_write_computed_tigs_fasta", type_hint=File()), doc=OutputDocumentation(doc="Write computed tigs to fasta  output file 'fasta'")), ToolOutput(tag="out_write_computed_tigs_fastq", output_type=File(optional=True), selector=InputSelector(input_to_select="in_write_computed_tigs_fastq", type_hint=File()), doc=OutputDocumentation(doc="Write computed tigs to fastq  output file 'fastq'"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Utgcns_V0_1_0().translate("wdl", allow_empty_container=True)

